# pytorch for Raspberry Pi

## Compiled pytorch release specifically for the latest Raspberry OS and Raspberry Pi

## Based on pytorch version  v1.7.1/57bffc3
## https://github.com/pytorch/pytorch

### Tested to work on the latest vanilla Raspberry Pi OS and Raspberry Pi 4
